#include "testlib.h"
#include <cmath>

using namespace std;
typedef long long ll;

const int L = 6, base = 30, mask = (1 << base) - 1;

struct big_int {
    int num[L];
    big_int() {
        memset(num, 0, sizeof num);
    }
    big_int(ll x) {
        memset(num, 0, sizeof num);
        num[0] = x & mask;
        num[1] = x >> base;
    }

    big_int operator*(big_int const& other) const {
        big_int ret;
        for (int i = 0; i < L; ++i) {
            ll carry = 0;
            for (int j = i; j < L; ++j) {
                carry += (ll) num[i] * other.num[j - i];
                carry += ret.num[j];
                ret.num[j] = carry & mask;
                carry >>= base;
            }
        }
        return ret;
    }

    bool operator<(big_int const& other) const {
        for (int i = L - 1; i >= 0; --i) {
            if (num[i] != other.num[i]) {
                return num[i] < other.num[i];
            }
        }
        return false;
    }

    bool operator>(big_int const& other) const {
        return other.operator<(*this);
    }

    bool operator<=(big_int const& other) const {
        return !(operator>(other));
    }
};

ll calc(ll a, ll b) {
    ll ret = sqrt((long double) a * b);
    big_int p = (big_int) a * (big_int) b;
    while ((big_int) ret * (big_int) ret > p) {
        --ret;
    }
    while ((big_int) (ret + 1) * (big_int) (ret + 1) <= p) {
        ++ret;
    }

    return ret;
}

long long x, y, z;

bool check(long long a, long long b, long long c) {
    if (a == 0 || b == 0 || c == 0) {
        return false;
    }
    if (calc(a, b) != x) {
        return false;
    }
    if (calc(a, c) != y) {
        return false;
    }
    if (calc(b, c) != z) {
        return false;
    }
    return true;
}

int main(int argc, char *argv[]) {
    registerTestlibCmd(argc, argv);
    constexpr long long limit = 1000000000000000000;

    int n = inf.readInt();

    for (int i = 0; i < n; i++) {
        x = inf.readLong();
        y = inf.readLong();
        z = inf.readLong();

        long long a = ouf.readLong(0, limit), b = ouf.readLong(0, limit), c = ouf.readLong(0, limit);
        long long at = ans.readLong(0, limit), bt = ans.readLong(0, limit), ct = ans.readLong(0, limit);

        bool ouf_ok = check(a, b, c);
        bool jury_ok = check(at, bt, ct);

        if (!jury_ok) {
            if (at != 0 || bt != 0 || ct != 0) {
                quitf(_fail, "Jury has non-zeroes in not matching answer on test %d", i);
            } else if (ouf_ok) {
                quitf(_fail, "Contestant has answer, jury doesn't on test %d", i);
            } else if (a != 0 || b != 0 || c != 0) {
                quitf(_wa, "Contestant has not matching answer on test %d", i);
            }
        } else {
            if (!ouf_ok) {
                quitf(_wa, "Jury has answer, contestant doesn't on test %d", i);
            }
        }
    }

    quitf(_ok, "All tests passed");
}
