// Checker created by Nikolay Budin

#ifdef DEBUG
#  define _GLIBCXX_DEBUG
#endif
#include <bits/stdc++.h>
#include <ext/pb_ds/assoc_container.hpp>
#include "testlib.h"
#define ff first
#define ss second
#define szof(x) ((int)x.size())
#ifndef LOCAL
#  define cerr __get_ce
#endif

using namespace std;
typedef long long ll;
typedef long double ld;
typedef pair<int, int> pii;
typedef unsigned long long ull;

using namespace __gnu_pbds;
template <typename T> using ordered_set = tree<T, null_type, less<T>, rb_tree_tag, tree_order_statistics_node_update>;
template <typename K, typename V> using ordered_map = tree<K, V, less<K>, rb_tree_tag, tree_order_statistics_node_update>;

int const INF = (int)1e9 + 1e3;
ll const INFL = (ll)1e18 + 1e6;

const long double eps = 1e-6;
const long double PI = atan2((long double) 0, (long double) -1);

struct point {
	long double x, y;
	point(long double _x, long double _y) : x(_x), y(_y) {}

	point operator+(point const& other) const {
		return point(x + other.x, y + other.y);
	}

	point operator-(point const& other) const {
		return point(x - other.x, y - other.y);
	}

	long double len() const {
		return sqrt(x * x + y * y);
	}
};

long double cross(point const& p1, point const& p2) {
	return p1.x * p2.y - p1.y * p2.x;
}

long double dot(point const& p1, point const& p2) {
	return p1.x * p2.x + p1.y * p2.y;
}

long double get_dist(point const& a, point const& b, point const& p) {
	if (dot(b - a, p - a) < 0) {
		return (a - p).len();
	}
	if (dot(a - b, p - b) < 0) {
		return (b - p).len();
	}

	return abs(cross(b - a, p - a) / (b - a).len());
}

int main(int argc, char* argv[]) {
	setName("compare two outputs");
	registerTestlibCmd(argc, argv);

	int t = inf.readInt();

	for (int tn = 1; tn <= t; ++tn) {
		setTestCase(tn);
		vector<point> points;
		int n = inf.readInt();
		for (int i = 0; i < n; ++i) {
			int x = inf.readInt();
			int y = inf.readInt();
			points.push_back(point(x, y));
		}

		auto check_out = [&](auto& stream) {
			int m = stream.readInt();
			stream.ensuref(m >= 3, "non-degenerate polygon should have at least 3 vertices");
			vector<point> poly;
			for (int i = 0; i < m; ++i) {
				long double x = stream.readDouble();
				long double y = stream.readDouble();
				poly.push_back(point(x, y));
			}

			long double ang = 0;
			for (int i = 0; i < m; ++i) {
				int next = (i + 1) % m;
				int next2 = (next + 1) % m;
				point v1 = poly[next] - poly[i];
				point v2 = poly[next2] - poly[next];
				stream.ensuref(cross(v1, v2) > 0, "polygon should be convex and given in counter-clockwise order");
				ang += atan2(cross(v1, v2), dot(v1, v2));
			}

			stream.ensuref(abs(ang - PI * 2) < 0.1, "sum of external angles should be equal to 2 * pi");

			for (int i = 0; i < n; ++i) {
				auto& p = points[i];
				long double d = 1e100;
				for (int j = 0; j < m; ++j) {
					int next = (j + 1) % m;
					d = min(d, get_dist(poly[j], poly[next], p));
				}
				stream.ensuref(d <= eps, "vertex #%d of initial polygon lies too far from the border of new polygon (%lf instead of %lf)", i + 1, (double) d, (double) eps);
			}

			return m;
		};

		int jans = check_out(ans);
		int pans = check_out(ouf);

		if (jans < pans) {
			quitf(_wa, "participant found polygon with %d vertices, but jury have the one with %d vertices", pans, jans);
		}

		if (pans < jans) {
			quitf(_fail, "participant found polygon with %d vertices, but jury have only the one with %d vertices", pans, jans);
		}
	}

	quitf(_ok, "participant found correct polygon for every testcase");

	return 0;
}