#define sz(x) (static_cast<int>((x).size()))
#include "testlib.h"
#include <unordered_map>
#include <unordered_set>
using namespace std;
const int MIN_K = 1;
const int MAX_K = 5;
int ensure_clique_or_anticlique(InStream& in, const vector<pair<int, int>>& graph, const vector<int>& vertices)
{
	int vertices_number = sz(vertices);
	in.ensuref(vertices_number >= MIN_K, "the set should contain at least %d vertices, but it consists of %d", MIN_K, vertices_number);
	in.ensuref(vertices_number <= MAX_K, "the set should contain at most %d vertices, but it consists of %d", MAX_K, vertices_number);
	if (vertices_number <= 1)
		return 2;
	unordered_map<int, int> interesting_vertices;
	for (int i = 0; i < vertices_number; ++i)
	{
		bool past_occurence = interesting_vertices.count(vertices[i]);
		int past_occurence_number = interesting_vertices[vertices[i]];
		in.ensuref(past_occurence == false, "%d%s and %d%s vertices of the set are both %d",
			past_occurence_number + 1, englishEnding(past_occurence_number + 1).c_str(),
			i + 1, englishEnding(i + 1).c_str(), vertices[i] + 1);
		interesting_vertices[vertices[i]] = i;
	}
	int edge = -1;
	vector<unordered_set<int>> neighbors(vertices_number);
	for (int i = 0; i < sz(graph); ++i)
		if (interesting_vertices.count(graph[i].first) && interesting_vertices.count(graph[i].second))
		{
			if (edge == -1)
				edge = i;
			neighbors[interesting_vertices[graph[i].first]].insert(graph[i].second);
		}
	if (edge == -1)
		return 0;
	for (int i = 0; i < vertices_number - 1; ++i)
		for (int j = i + 1; j < vertices_number; ++j)
			in.ensuref(neighbors[i].count(vertices[j]) || neighbors[j].count(vertices[i]),
				"the set is neither an anticlique since v_%d = a_%d = %d and v_%d = b_%d = %d are connected, nor a clique since v_%d = %d and v_%d = %d are disconnected",
				interesting_vertices[graph[edge].first] + 1, edge + 1, graph[edge].first + 1,
				interesting_vertices[graph[edge].second] + 1, edge + 1, graph[edge].second + 1,
				i + 1, vertices[i] + 1, j + 1, vertices[j] + 1);
	return 1;
}
int check_answer(InStream& in, const vector<pair<int, int>>& graph, const int n, const int k, const int l)
{
	vector<int> vertices;
	for (int i = 0; !in.seekEof(); ++i)
	{
		vertices.push_back(in.readInt(i == 0 ? -1 : 1, n, format("v_%d", i + 1)));
		if (vertices.back() == -1)
			return -1;
		in.ensuref(vertices.back(), "v_%d should be nonzero", i + 1);
		--vertices.back();
	}
	int result = ensure_clique_or_anticlique(in, graph, vertices);
	if (result == 0)
	{
		in.ensuref(vertices.size() == k, "%d-anticlique was found, but %d-anticlique was asked for", vertices.size(), k);
		return 0;
	}
	else if (result == 1)
	{
		in.ensuref(vertices.size() == l, "%d-clique was found, but %d-clique was asked for", vertices.size(), l);
		return 1;
	}
	else if (k == 1)
		if (l == 1)
			return 2;
		else
			return 0;
	else
		if (l == 1)
			return 1;
		else
			in.ensuref(false, "%d-set was found, but %d-anticlique or %d-clique were asked for", vertices.size(), k, l);
}
int main(int argc, char** argv)
{
	registerTestlibCmd(argc, argv);
	int n = inf.readInt();
	int m = inf.readInt();
	int k = inf.readInt();
	int l = inf.readInt();
	vector<pair<int, int>> graph(m);
	for (int i = 0; i < m; ++i)
	{
		graph[i].first = inf.readInt() - 1;
		graph[i].second = inf.readInt() - 1;
	}
	int ja = check_answer(ans, graph, n, k, l);
	int pa = check_answer(ouf, graph, n, k, l);
	if ((ja == -1) == (pa == -1))
		if (ja == -1)
			quitf(_ok, "there are no %d-anticliques or %d-cliques", k, l);
		else if (pa == 0)
			quitf(_ok, "participant found %d-anticlique", k);
		else if (pa == 1)
			quitf(_ok, "participant found %d-clique", l);
		else
			quitf(_ok, "participant found %d-set", k);
	else if (ja == -1)
		if (pa == 0)
			quitf(_fail, "participant found %d-anticlique but jury found nothing", k);
		else if (pa == 1)
			quitf(_fail, "participant found %d-clique but jury found nothing", l);
		else
			quitf(_fail, "participant found %d-set but jury found nothing", k);
	else if (ja == 0)
		quitf(_wa, "jury found %d-anticlique but participant found nothing", k);
	else if (ja == 1)
		quitf(_wa, "jury found %d-clique but participant found nothing", l);
	else
		quitf(_wa, "jury found %d-set but participant found nothing", k);
}